@@ -7,6 +7,7 @@ import (
 	"oh-my-posh/engine"
 	"oh-my-posh/environment"
 	"oh-my-posh/shell"
+	"time"
 
 	"github.com/spf13/cobra"
 )
@@ -15,15 +16,18 @@ import (
 var debugCmd = &cobra.Command{
 	Use:   "debug",
 	Short: "Print the prompt in debug mode",
-	Long:  "Print the prompt in debug mode",
+	Long:  "Print the prompt in debug mode.",
 	Args:  cobra.NoArgs,
 	Run: func(cmd *cobra.Command, args []string) {
+		startTime := time.Now()
 		env := &environment.ShellEnvironment{
+			Version: cliVersion,
 			CmdFlags: &environment.Flags{
 				Config: config,
+				Debug:  true,
 			},
 		}
-		env.Init(true)
+		env.Init()
 		defer env.Close()
 		cfg := engine.LoadConfig(env)
 		ansi := &color.Ansi{}
@@ -47,7 +51,7 @@ var debugCmd = &cobra.Command{
 			Ansi:         ansi,
 			Plain:        plain,
 		}
-		fmt.Print(eng.PrintDebug(cliVersion))
+		fmt.Print(eng.PrintDebug(startTime, cliVersion))
 	},
 }
 
