@@ -103,6 +103,8 @@ const (
 	GitlabIcon properties.Property = "gitlab_icon"
 	// GitIcon shows when the upstream can't be identified
 	GitIcon properties.Property = "git_icon"
+	// UntrackedModes list the optional untracked files mode per repo
+	UntrackedModes properties.Property = "untracked_modes"
 
 	DETACHED     = "(detached)"
 	BRANCHPREFIX = "ref: refs/heads/"
@@ -269,7 +271,8 @@ func (g *Git) setGitStatus() {
 	g.UpstreamGone = true
 	g.Working = &GitStatus{}
 	g.Staging = &GitStatus{}
-	output := g.getGitCommandOutput("status", "-unormal", "--branch", "--porcelain=2")
+	untrackedMode := g.getUntrackedFilesMode()
+	output := g.getGitCommandOutput("status", untrackedMode, "--branch", "--porcelain=2")
 	for _, line := range strings.Split(output, "\n") {
 		if strings.HasPrefix(line, HASH) && len(line) >= len(HASH)+7 {
 			g.Hash = line[len(HASH) : len(HASH)+7]
@@ -542,3 +545,12 @@ func (g *Git) convertToLinuxPath(path string) string {
 	}
 	return g.env.ConvertToLinuxPath(path)
 }
+
+func (g *Git) getUntrackedFilesMode() string {
+	mode := "normal"
+	repoModes := g.props.GetKeyValueMap(UntrackedModes, map[string]string{})
+	if val := repoModes[g.gitRealFolder]; len(val) != 0 {
+		mode = val
+	}
+	return fmt.Sprintf("-u%s", mode)
+}
